<?php
/**
 * PHPExcel
 *
 * Copyright (C) 2006 - 2014 PHPExcel
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 *
 * @category   PHPExcel
 * @package    PHPExcel
 * @copyright  Copyright (c) 2006 - 2014 PHPExcel (http://www.codeplex.com/PHPExcel)
 * @license    http://www.gnu.org/licenses/old-licenses/lgpl-2.1.txt	LGPL
 * @version    1.8.0, 2014-03-02
 */

/** Error reporting */
error_reporting(E_ALL);
ini_set('display_errors', TRUE);
ini_set('display_startup_errors', TRUE);
date_default_timezone_set('Europe/London');

if (PHP_SAPI == 'cli')
	die('This example should only be run from a Web Browser');

/** Include PHPExcel and MySQLi db */
require_once dirname(__FILE__) . '/Classes/DB.php';
require_once dirname(__FILE__) . '/Classes/PHPExcel.php';

//Create DB object
use DB\MySQLi;

$hostname = 'localhost';
$username = 'root';
$password = '';
$database = 'workforce';

$db = new MySQLi($hostname, $username, $password, $database);

$query = $db->query("SELECT * FROM employees");

$dataArr = $query->rows;

//This will become our top header row
$headerRowArr = array(array('id', 'fname', 'lname', 'email', 'phone', 'company'));

array_splice($dataArr,0,0,$headerRowArr);

$excelDataArr = array();

/*
 * The PHPExcel Library can designate a cell's location in a matrix as 
 * (column, row) i.e. (0,1), (1,1), (2,1)...
 * e.g. A1 becomes (0,1), B1 becomes (1,1) and C1 becomes (2,1).. and so on..
 * Notice that the columns start from 0 and rows start from 1
 * So to achieve an array which will have keys matching this columns and rows format, we'll
 * apply the following logic in the foreach loop 
 */
$i = 1;
foreach($dataArr as $key => $val){
	foreach($val as $value){
		$excelDataArr[$i][] = $value;
	}
	$i++;	
}

$objPHPExcel = new PHPExcel();

// Set properties
$objPHPExcel->getProperties()->setCreator("TheDevLogs")
			->setLastModifiedBy("Brajinder Singh")
			->setTitle("Office 2007 XLSX Export Document")
			->setSubject("Office 2007 XLSX Export Document")
			->setDescription("Exported doc for Office 2007 XLSX, generated by PHPExcel.")
			->setKeywords("office EXCEL 2007 PHPExcel XLSX php")
			->setCategory("Exported file");
$objPHPExcel->getActiveSheet()->setTitle('TheDevLogs Excel Export');

foreach($excelDataArr as $row => $val){
	foreach($val as $column => $value){
		$objPHPExcel->setActiveSheetIndex(0)->setCellValueByColumnAndRow($column, $row, $value);
	}
}

//Style the first header row to be bold and have borders
$styleArray = array(
    'font' => array(
        'bold' => true,
    ),
    'alignment' => array(
        'horizontal' => PHPExcel_Style_Alignment::HORIZONTAL_LEFT,
    ),
    'borders' => array(
        'allborders' => array(
            'style' => PHPExcel_Style_Border::BORDER_THIN,
        )
    )
);


$objPHPExcel->getActiveSheet()->getStyle('A1:F1')->applyFromArray($styleArray);

$objWriter = PHPExcel_IOFactory::createWriter($objPHPExcel, 'Excel2007');

$location = __DIR__.'/files/excel/'; //Make sure this location exists

$objWriter->save($location.'MyExcelSheet.xlsx');

echo 'File created: '.$location.'MyExcelSheet.xlsx';
